#ifndef CGAL_CURVE_2_H
#define CGAL_CURVE_2_H

#include "Types.h"

//  Abstract template class Curve_2 implements a general curve in 2D.
//  Template parameters:
//       NumType_      number type for coordinates

template <class NumType_> 
class Curve_2 {

public:
    typedef NumType_ NumType;
    typedef CGAL::Cartesian<NumType> REP;
    typedef CGAL::Point_2<REP> Point;
    typedef list<Point> PointList;
    typedef PointList::iterator PointListIt;
    typedef vector<Point> Points;
    typedef Points::iterator PointIt;     
    typedef CGAL::Segment_2<REP> Segment;
    typedef list<Segment> SegmentList;    
    typedef vector<Segment> Segments;   
    typedef CGAL::Vector_2<REP> Vector;
    typedef vector<Vector> Vectors;    
             
    // draw: void -> void   
    // Effect: opens a GeoWin window and draws the curve
    // pure virtual function should be overwritten in the derived classes
    virtual void draw() = 0;        

    // has_on: Point -> bool
    // Parameters: 
    //    pt       the point which should be testet if it is on the curve
    //    epsilon  the upper bound for the distance from pt to the 
    //             approximation of the curve
    // Returns: true, if pt lies on the curve (distance(pt, curve)<=epsilon)
    //          false otherwise
    // Tests if the point pt lies on the curve.
    virtual bool has_on(const Point& pt, NumType epsilon) const = 0;    
};
#endif //CGAL_CURVE_2_H










