#ifndef HYPERBEL_HELIX_X_FO_H
#define HYPERBEL_HELIX_X_FO_H

#include <math.h>
#include "Types.h"
#include "Helpers.h"


// Template function object class which calculates the x-coordinate
// of a point at a hyperbel helix for a given parameter value t
// Parameters:
//    NumType_    the number type of the points coordinates
template <class NumType_> 
class Hyperbel_helix_x {

public:
    typedef CGAL::Cartesian<NumType_> REP;
    typedef CGAL::Point_2<REP> Point;
    typedef list<Point> PointList;
    typedef vector<Point> Points; 
    
    static const double PI = 3.14159265;
    
    Hyperbel_helix_x(const Point& center=CGAL::ORIGIN, NumType_ a = 1) {
	center_ = center;	
	a_ = a;
    }    

    NumType_ operator() (NumType_ t) const {
	NumType_ coef = a_*t;
	return (center_.x() + cos(_to_float(t))/coef);
    }

private:
    Point center_;    
    NumType_ a_;
};
#endif //HYPERBEL_HELIX_X_FO_H
